@@ -7,7 +7,7 @@ feature_schema = Schema({
     'type': And(str, Use(str.lower), lambda s: s in COLUMN_DATA_TYPES.get_attributes().values()),
     Optional('encoder_class'): object,
     Optional('encoder_attrs'): dict,
-    Optional('depends_on_column'): str,
+    Optional('depends_on_column'): list,
     Optional('dropout'): float,
     Optional('weights'): dict,
     Optional('secondary_type'): And(str, Use(str.lower), lambda s: s in COLUMN_DATA_TYPES.get_attributes().values()),
