@@ -6,12 +6,13 @@ from sklearn.preprocessing import MinMaxScaler
 
 def tensor_from_series(series, device, n_dims, pad_value, max_len=None, normalizer=None):
     """
-    :param series: list of lists, corresponds to time series: [[x1_1, ..., x1_n], [x2_1, ..., x2_n], ...]
-                   the series is zero-padded on each axis so that all dimensions have equal length
+    :param series: list of lists, corresponds to a time series: [[x1_1, ..., x1_n], [x2_1, ..., x2_n], ...]
+                   the series will be padded to be (1, ts_length, n_dims)-shaped
     :param device: computing device that PyTorch backend uses
-    :param n_dims: will zero-pad dimensions until series_dimensions == n_dims
-    :param pad_value: value to pad each dimension in the time series, if needed
-    :param max_len: length to pad or truncate each time_series
+    :param n_dims: number of features in the time series
+    :param pad_value: value to pad the time series with, if needed
+    :param max_len: number of timesteps in the time_series, automatically determined if it's not passed
+    :param normalizer: optional, should have an .encode() method
     :return: series as a tensor ready for model consumption, shape (1, ts_length, n_dims)
     """
     # conversion to float
@@ -21,20 +22,25 @@ def tensor_from_series(series, device, n_dims, pad_value, max_len=None, normaliz
     # timestep padding and truncating
     for i in range(len(series)):
         for _ in range(max(0, max_len - len(series[i]))):
-            series[i].append(pad_value)
+            series[i].insert(0, pad_value)
         series[i] = series[i][:max_len]
 
-    # dimension padding
-    for _ in range(max(0, n_dims - len(series))):
-        series.append([pad_value] * max_len)
-
-    # normalize and transpose
     if normalizer:
-        series = normalizer.transform(np.array(series))
-    tensor = torch.transpose(torch.tensor(series, dtype=torch.float, device=device), 0, 1)
+        if isinstance(normalizer, MinMaxNormalizer):
+            series = torch.Tensor([normalizer.encode(s)[0] for s in series]).transpose(0, 1)
+        else:
+            series = torch.Tensor([normalizer.encode(s) for s in series][0])
+    else:
+        series = torch.Tensor(series).transpose(0, 1)
 
-    # add batch dimension
-    return tensor.view(-1, max_len, n_dims)
+    # dimension padding
+    for _ in range(max(0, n_dims - series.shape[-1])):
+        pad = torch.full((series.shape[0], 1), pad_value)
+        series = torch.cat([series, pad], dim=-1)
+
+    # remove nans and add batch dimension
+    series[torch.isnan(series)] = 0.0
+    return series.unsqueeze(0).to(device)
 
 
 class DecoderRNNNumerical(nn.Module):
@@ -43,7 +49,7 @@ class DecoderRNNNumerical(nn.Module):
         self.hidden_size = hidden_size
         self.in_activation = nn.Sigmoid()
         self.dropout = nn.Dropout(0.2)
-        self.gru = nn.GRU(output_size, hidden_size)
+        self.gru = nn.GRU(output_size, hidden_size, batch_first=True)
         self.out = nn.Linear(hidden_size, output_size)
 
     def forward(self, input, hidden):
@@ -53,8 +59,8 @@ class DecoderRNNNumerical(nn.Module):
         output = self.out(output)
         return output, hidden
 
-    def initHidden(self, device):
-        return torch.zeros(1, 1, self.hidden_size, device=device)
+    def initHidden(self, device, batch_size=1):
+        return torch.zeros(1, batch_size, self.hidden_size, device=device)
 
 
 class EncoderRNNNumerical(nn.Module):
@@ -71,8 +77,8 @@ class EncoderRNNNumerical(nn.Module):
         output = self.out(output)
         return output, hidden
 
-    def initHidden(self, device):
-        return torch.zeros(1, 1, self.hidden_size, device=device)
+    def initHidden(self, device, batch_size=1):
+        return torch.zeros(1, batch_size, self.hidden_size, device=device)
 
 
 class MinMaxNormalizer:
@@ -80,16 +86,14 @@ class MinMaxNormalizer:
         self.scaler = MinMaxScaler()
         self.factor = factor
 
-    def fit(self, x):
+    def prepare(self, x):
         X = np.array([j for i in x for j in i]).reshape(-1, 1)
         self.scaler.fit(X)
 
-    def transform(self, y):
+    def encode(self, y):
+        if not isinstance(y[0], list):
+            y = np.array(y).reshape(1, -1)
         return self.scaler.transform(y)
 
-    def fit_transform(self, x):
-        self.fit(x)
-        return self.transform(x)
-
-    def inverse_transform(self, y):
+    def decode(self, y):
         return self.scaler.inverse_transform(y)
